==> qtjambi-designer-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiDesigner/QDesignerCustomWidgetCollectionInterface_shell.cpp <==
#include "QDesignerCustomWidgetCollectionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QDesignerCustomWidgetCollectionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDesignerCustomWidgetCollectionInterface")
    QDesignerCustomWidgetCollectionInterface *_ptr = reinterpret_cast<QDesignerCustomWidgetCollectionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDesignerCustomWidgetCollectionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDesignerCustomWidgetCollectionInterface_shell) ); }

jmethodID QDesignerCustomWidgetCollectionInterface_shell::__shell_javaMethod(int pos) const { return QDesignerCustomWidgetCollectionInterface_shell::__shell()->javaMethod(typeid(QDesignerCustomWidgetCollectionInterface), pos); }

// emitting (writeShellConstructor)
QDesignerCustomWidgetCollectionInterface_shell::QDesignerCustomWidgetCollectionInterface_shell()
    : QDesignerCustomWidgetCollectionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDesignerCustomWidgetCollectionInterface::QDesignerCustomWidgetCollectionInterface_shell()", QDesignerCustomWidgetCollectionInterface_shell::__shell())
    QDesignerCustomWidgetCollectionInterface_shell::__shell()->constructed(typeid(QDesignerCustomWidgetCollectionInterface));
}

// emitting (writeShellDestructor)
QDesignerCustomWidgetCollectionInterface_shell::~QDesignerCustomWidgetCollectionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDesignerCustomWidgetCollectionInterface::~QDesignerCustomWidgetCollectionInterface()", QDesignerCustomWidgetCollectionInterface_shell::__shell())
    QDesignerCustomWidgetCollectionInterface_shell::__shell()->destructed(typeid(QDesignerCustomWidgetCollectionInterface));
}

void QDesignerCustomWidgetCollectionInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDesignerCustomWidgetCollectionInterface_shell*>(ptr)->QDesignerCustomWidgetCollectionInterface_shell::__shell()->tryDeleteShell(typeid(QDesignerCustomWidgetCollectionInterface));
}

// emitting Virtual overrides (virtualFunctions)
QList<QDesignerCustomWidgetInterface*> QDesignerCustomWidgetCollectionInterface_shell::customWidgets() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDesignerCustomWidgetCollectionInterface::", QDesignerCustomWidgetCollectionInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QList<QDesignerCustomWidgetInterface*>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QDesignerCustomWidgetCollectionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QDesignerCustomWidgetCollectionInterface_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QList<QDesignerCustomWidgetInterface*> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QDesignerCustomWidgetCollectionInterface_shell::__shell()->warnForMethod("QDesignerCustomWidgetCollectionInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDesignerCustomWidgetCollectionInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QList<QDesignerCustomWidgetInterface *>();
        }
    }else{
        return QList<QDesignerCustomWidgetInterface *>();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDesignerCustomWidgetCollectionInterface_access::__qt_customWidgets_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QDesignerCustomWidgetCollectionInterface::customWidgets() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QDesignerCustomWidgetCollectionInterface::customWidgets() const.";
    } else {
        QList<QDesignerCustomWidgetInterface*> __qt_return_value = customWidgets();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QDesignerCustomWidgetCollectionInterface()
void __qt_construct_QDesignerCustomWidgetCollectionInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDesignerCustomWidgetCollectionInterface()")
    Q_UNUSED(__java_arguments)
    QDesignerCustomWidgetCollectionInterface *__qt_this = new(__qtjambi_ptr) QDesignerCustomWidgetCollectionInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDesignerCustomWidgetCollectionInterface::QDesignerCustomWidgetCollectionInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerCustomWidgetCollectionInterface_00024Impl_initialize_1native__Lio_qt_designer_QDesignerCustomWidgetCollectionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesignerCustomWidgetCollectionInterface::QDesignerCustomWidgetCollectionInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDesignerCustomWidgetCollectionInterface, sizeof(QDesignerCustomWidgetCollectionInterface_shell), typeid(QDesignerCustomWidgetCollectionInterface), true, &deleter_QDesignerCustomWidgetCollectionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDesignerCustomWidgetCollectionInterface_shell
void __qt_destruct_QDesignerCustomWidgetCollectionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDesignerCustomWidgetCollectionInterface")
    reinterpret_cast<QDesignerCustomWidgetCollectionInterface_shell*>(ptr)->~QDesignerCustomWidgetCollectionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDesignerCustomWidgetCollectionInterface::customWidgets()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerCustomWidgetCollectionInterface_00024Impl_00024ConcreteWrapper_customWidgets_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDesignerCustomWidgetCollectionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QDesignerCustomWidgetCollectionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDesignerCustomWidgetCollectionInterface::customWidgets()const", __qt_this)
        __java_return_value = static_cast<const QDesignerCustomWidgetCollectionInterface_access*>(__qt_this)->__qt_customWidgets_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDesignerCustomWidgetCollectionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QDesignerCustomWidgetCollectionInterface>("QDesignerCustomWidgetCollectionInterface", "io/qt/designer/QDesignerCustomWidgetCollectionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "customWidgets", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QDesignerCustomWidgetCollectionInterface, {
        ConstructorInfo(&__qt_construct_QDesignerCustomWidgetCollectionInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDesignerCustomWidgetCollectionInterface);
    registerSizeOfShell(typeId, sizeof(QDesignerCustomWidgetCollectionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QDesignerCustomWidgetCollectionInterface* _object = dynamic_cast<QDesignerCustomWidgetCollectionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QDesignerCustomWidgetCollectionInterface *object = reinterpret_cast<QDesignerCustomWidgetCollectionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QDesignerCustomWidgetCollectionInterface *object = reinterpret_cast<const QDesignerCustomWidgetCollectionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-designer-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiDesigner/QDesignerCustomWidgetCollectionInterface_shell.cpp <==
#include "QDesignerCustomWidgetCollectionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QDesignerCustomWidgetCollectionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDesignerCustomWidgetCollectionInterface")
    QDesignerCustomWidgetCollectionInterface *_ptr = reinterpret_cast<QDesignerCustomWidgetCollectionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDesignerCustomWidgetCollectionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDesignerCustomWidgetCollectionInterface_shell) ); }

jmethodID QDesignerCustomWidgetCollectionInterface_shell::__shell_javaMethod(int pos) const { return QDesignerCustomWidgetCollectionInterface_shell::__shell()->javaMethod(typeid(QDesignerCustomWidgetCollectionInterface), pos); }

// emitting (writeShellConstructor)
QDesignerCustomWidgetCollectionInterface_shell::QDesignerCustomWidgetCollectionInterface_shell()
    : QDesignerCustomWidgetCollectionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDesignerCustomWidgetCollectionInterface::QDesignerCustomWidgetCollectionInterface_shell()", QDesignerCustomWidgetCollectionInterface_shell::__shell())
    QDesignerCustomWidgetCollectionInterface_shell::__shell()->constructed(typeid(QDesignerCustomWidgetCollectionInterface));
}

// emitting (writeShellDestructor)
QDesignerCustomWidgetCollectionInterface_shell::~QDesignerCustomWidgetCollectionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDesignerCustomWidgetCollectionInterface::~QDesignerCustomWidgetCollectionInterface()", QDesignerCustomWidgetCollectionInterface_shell::__shell())
    QDesignerCustomWidgetCollectionInterface_shell::__shell()->destructed(typeid(QDesignerCustomWidgetCollectionInterface));
}

void QDesignerCustomWidgetCollectionInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDesignerCustomWidgetCollectionInterface_shell*>(ptr)->QDesignerCustomWidgetCollectionInterface_shell::__shell()->tryDeleteShell(typeid(QDesignerCustomWidgetCollectionInterface));
}

// emitting Virtual overrides (virtualFunctions)
QList<QDesignerCustomWidgetInterface*> QDesignerCustomWidgetCollectionInterface_shell::customWidgets() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDesignerCustomWidgetCollectionInterface::", QDesignerCustomWidgetCollectionInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QList<QDesignerCustomWidgetInterface*>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QDesignerCustomWidgetCollectionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QDesignerCustomWidgetCollectionInterface_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QList<QDesignerCustomWidgetInterface*> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QDesignerCustomWidgetCollectionInterface_shell::__shell()->warnForMethod("QDesignerCustomWidgetCollectionInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDesignerCustomWidgetCollectionInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QList<QDesignerCustomWidgetInterface *>();
        }
    }else{
        return QList<QDesignerCustomWidgetInterface *>();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDesignerCustomWidgetCollectionInterface_access::__qt_customWidgets(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QDesignerCustomWidgetCollectionInterface::customWidgets() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QDesignerCustomWidgetCollectionInterface::customWidgets() const.";
    } else {
        QList<QDesignerCustomWidgetInterface*> __qt_return_value = customWidgets();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QDesignerCustomWidgetCollectionInterface_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QDesignerCustomWidgetCollectionInterface *__qt_this = new(__qtjambi_ptr) QDesignerCustomWidgetCollectionInterface_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QDesignerCustomWidgetCollectionInterface_shell
void __qt_destruct_QDesignerCustomWidgetCollectionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDesignerCustomWidgetCollectionInterface")
    reinterpret_cast<QDesignerCustomWidgetCollectionInterface_shell*>(ptr)->~QDesignerCustomWidgetCollectionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDesignerCustomWidgetCollectionInterface::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerCustomWidgetCollectionInterface_00024Impl_initialize_1native__Lio_qt_designer_QDesignerCustomWidgetCollectionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesignerCustomWidgetCollectionInterface::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDesignerCustomWidgetCollectionInterface_0, sizeof(QDesignerCustomWidgetCollectionInterface_shell), typeid(QDesignerCustomWidgetCollectionInterface), true, &deleter_QDesignerCustomWidgetCollectionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDesignerCustomWidgetCollectionInterface::customWidgets()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_designer_QDesignerCustomWidgetCollectionInterface_00024Impl_00024ConcreteWrapper_customWidgets_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDesignerCustomWidgetCollectionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QDesignerCustomWidgetCollectionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDesignerCustomWidgetCollectionInterface::customWidgets()const", __qt_this)
        __java_return_value = static_cast<const QDesignerCustomWidgetCollectionInterface_access*>(__qt_this)->__qt_customWidgets(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDesignerCustomWidgetCollectionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QDesignerCustomWidgetCollectionInterface>("QDesignerCustomWidgetCollectionInterface", "io/qt/designer/QDesignerCustomWidgetCollectionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "customWidgets", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QDesignerCustomWidgetCollectionInterface, {
        ConstructorInfo(&__qt_construct_QDesignerCustomWidgetCollectionInterface_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDesignerCustomWidgetCollectionInterface);
    registerSizeOfShell(typeId, sizeof(QDesignerCustomWidgetCollectionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QDesignerCustomWidgetCollectionInterface* _object = dynamic_cast<QDesignerCustomWidgetCollectionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QDesignerCustomWidgetCollectionInterface *object = reinterpret_cast<QDesignerCustomWidgetCollectionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QDesignerCustomWidgetCollectionInterface *object = reinterpret_cast<const QDesignerCustomWidgetCollectionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
